import Loading from '../utils/loading'
import {getConfig} from "../config/index";

//存储正在操作的请求
let taskMap = new Map();
let id = 0;
let online = true;
let timer = null;

/*
* 将请求全部存储到map
*/
export const setTask = async (fn, params, resolve, reject) => {
    taskMap.set(id, {
        time: +new Date(),
        fn,
        params,
        resolve,
        reject
    })
    // startTimer();
    return id++;
}
/**
 * 删除map存储的请求
 */
export const removeTask = (id) => {
    taskMap.delete(id)
}

/**
 * 网络改变 循环遍历所有未完成的请求
 */
const onNetworkStatusChange = async (isConnected) => {
    if (!online && taskMap.size > 0 && isConnected) {
        Loading.show("重新加载...");
        retrying();
    }
    online = isConnected;
}
/**
 * 定时去刷新任务列表
 */

const startTimer = () => {
    if (timer)
        return
    timer = setInterval(() => {
        retrying(true);
    }, 2000)
}

/**
 * 自动重试打开
 */
const retrying = (type) => {
    for (let task of taskMap) {
        if (task.time > +new Date() - getConfig().TIME_OUT)
            return;
        task[1].time = +new Date();
        const {fn, params, resolve, reject} = task[1];
        fn(...params, task[0], resolve, reject, !type);
    }
}

/**
 * 获取当前网络
 */
wx.getNetworkType({
    success: ({networkType}) => {
        online = networkType !== 'none';
    }
})

/**
 * 监听网络变化
 */
wx.onNetworkStatusChange(function ({isConnected}) {
    onNetworkStatusChange(isConnected);
})
