import {getConfig} from '../config/index'
import {arrayBufferToUTF8} from './index'
import {setTask, removeTask} from "../utils/network";
import Toast from '../utils/toast'
import {NET_WORK_ERROR_MESSAGE} from "../constants/index";

export default (url, data, method = 'GET', responseType = "text") => {
  return new Promise(async (resolve) => {
    let id = await setTask(request, [url, data, method], resolve,responseType);
    request(url, data, method, id, resolve, responseType);
  })
}

const request = (url, data, method, id, resolve, responseType, reject, showError = true,) => {
  if (method === 'GET') {
    if (data && data !== {}) {
      url += '?';
      for (const key in data) {
        url = url + key + "=" + data[key] + '&';
      }
    }
  }
  const header = {
    "Content-Type": "application/json"
  };
  if (global.userInfo) {
    const token = global.userInfo.token;
    const port = global.userInfo.loginPort;
    const id = global.userInfo.loginuserId;
    const loginName = global.userInfo.loginuserDto && global.userInfo.loginuserDto.loginName;
    if (token)
      header["Header-Token"] = token;
    if (port)
      header["Header-LoginPort"] = port;
    if (id)
      header["Header-UserId"] = id;
    if (loginName)
      header["Header-UserName"] = encodeURI(loginName);
  }
  const conf = getConfig();
  const options = {
    method: method,
    url: `${conf.BASE_URL}${url}`,
    timeout: conf.TIME_OUT,
    header: header,
    responseType,
    success: (ret) => {
      if (ret.statusCode === 200) {

        if (responseType === 'arraybuffer') {
          try {
            const string = arrayBufferToUTF8(ret.data);
            if (string)
              ret.data = JSON.parse(string)
          } catch (e) {
          }
        }

        if (!ret.data.success && ret.data.errors && ret.data.errors[0].code === "60022") {
          wx.navigateTo({
            url: '/pages/login/index'
          })
        }
        resolve(ret.data)
      } else {
        resolve({
          success: false,
          errors: [{
            message: '系统出错,稍后重试',
            errorCode: ret.statusCode
          }]
        })
      }
      removeTask(id);
    },
    fail: () => {
      showError && Toast.showMessage(NET_WORK_ERROR_MESSAGE)
    }
  };
  if (method === 'POST')
    options.data = data;
  wx.request(options);
}
